/****************************************************************************/
/* Name: EuroCalc.rex                                                       */
/* Type: Object REXX Script using OODialog                                  */
/* Author:                                                                  */
/* Resource: Eurocalc.rc                                                    */
/*                                                                          */
/* Description:                                                             */
/* This file has been created by the Object REXX Workbench OODIALOG         */
/* template generator.                                                      */
/*                                                                          */
/* Copyright (C) ____________________, 1999. All Rights Reserved.           */
/*                                                                          */
/****************************************************************************/

/* Install signal handler to catch error conditions and clean up */
signal on any name CleanUp

MyDialog = .MyDialogClass~new
if MyDialog~InitCode = 0 then do
  rc = MyDialog~Execute("SHOWTOP")
end

/* Add program code here */
exit   /* leave program */


/* ---- signal handler to destroy dialog if error condition was raised  ----*/
CleanUp:
   call ErrorMessage "Error" rc "occurred at line" sigl":" errortext(rc),
                     || "a"x || condition("o")~message
   if MyDialog~IsDialogActive then MyDialog~StopIt


::requires "OODIALOG.CLS"    /* This file contains the OODIALOG classes */

::requires "pgm_07+08-2.cmd" /* RGF, definiert die Euroklasse */

/* ---------------------------- Directives ---------------------------------*/

::class MyDialogClass subclass UserDialog

::method Init
  expose euroList euroDir

  forward class (super) continue /* call parent constructor */
  InitRet = Result
/*
  if self~Load("C:\pgm.rgf\ObjREXX\temp\Eurocalc.rc", ) \= 0 then do
*/
  if self~Load(".\Eurocalc.rc", ) \= 0 then do
     self~InitCode = 1
     return 1
  end

  /* Connect dialog control items to class methods */
  self~ConnectButton(1,"Ok")
  self~ConnectButton(2,"Cancel")

  /* Initial values that are assigned to the object attributes */
  self~INPUT= ''                                     /* Entry Line */

  /* Add your initialization code here */
  euroList = .list~of( "EUR", "ATS", "BEF", "DEM", "FIM", "FRF", "IEP", "ITL",,
                       "LUF", "NLG", "PTE", "ESP", "GRD" )

  euroDir = .directory~new
  euroDir~ATS = .euro ~ NEW("ATS", "Austria",     "Schilling",   13.7603   )
  euroDir~BEF = .euro ~ NEW("BEF", "Belgium",     "Franc",       40.3399   )
  euroDir~DEM = .euro ~ NEW("DEM", "Germany",     "Mark",         1.95583  )
  euroDir~FIM = .euro ~ NEW("FIM", "Finland",     "Mark",         5.94573  )
  euroDir~FRF = .euro ~ NEW("FRF", "France",      "Franc",        6.55957  )
  euroDir~IEP = .euro ~ NEW("IEP", "Ireland",     "Pound",        0.787564 )
  euroDir~ITL = .euro ~ NEW("ITL", "Italy",       "Lira",      1936.27     )
  euroDir~LUF = .euro ~ NEW("LUF", "Luxembourg",  "Franc",       40.3399   )
  euroDir~NLG = .euro ~ NEW("NLG", "Netherlands", "Gulden",       2.20371  )
  euroDir~PTE = .euro ~ NEW("PTE", "Portugal",    "Escudo",     200.482    )
  euroDir~ESP = .euro ~ NEW("ESP", "Spain",       "Peseta",     166.386    )
  euroDir~GRD = .euro ~ NEW("GRD", "Greece",      "Drachmen",   340.750    )
  euroDir~EUR = .euro ~ NEW("EUR", "Europe",      "Euro",         1.0000   )
  return InitRet


::method InitDialog
  expose euroDir euroList
  InitDlgRet = self~InitDialog:super

  /* Initialization Code (e.g. fill list and combo boxes) */

  /* RGF-Show values */
  self~dsp_euro                      /* show present values */

  return InitDlgRet

/* --------------------- message handler -----------------------------------*/

  /* Method Ok is connected to item 1 */
::method Ok
  self~DoTheWork                                                                                                                                        /* RGF          */
/*
  resOK = self~OK:super  /* make sure self~Validate is called and self~InitCode is set to 1 */
  self~Finished = resOK  /* 1 means close dialog, 0 means keep open */
  return resOK
*/

  /* Method Cancel is connected to item 2 */
::method Cancel
  resCancel = self~Cancel:super  /* make sure self~InitCode is set to 2 */
  self~Finished = resCancel      /* 1 means close dialog, 0 means keep open */
  return resCancel


::method DoTheWork
  expose euroDir

  /* parse first three words, translate them into uppercase       */
  PARSE UPPER VALUE self~getValue("input") WITH Amount InputCurrency .

  /* RGF - clear message fields */
  self~rgf_msg("MSG1", center(date("S") time(), 50 ))
  self~rgf_msg("MSG2", LEFT("", 50 ))

  IF Amount = "" THEN      /* nothing given, show exchange rates  */
  DO
    self~set_euro(1)            /* set all euro-objects to one Euro: result is x-change-rate */
    self~rgf_msg("MSG2", "(Exchange rates)" )
    return
  END

  IF DATATYPE(Amount, "Number") = .false THEN
  DO
     self~rgf_msg("MSG2", "InputCurrency not a number!" )
     call beep 500, 10
     RETURN
  END

  IF InputCurrency = "" THEN InputCurrency = "EUR"
  ELSE IF \euroDir~hasindex( InputCurrency ) THEN
  DO
     self~rgf_msg("MSG2", "Unknown currency given!" )
     call beep 500, 10
     RETURN
  END
  tmpEuro = euroDir~entry(InputCurrency)        /* get appropriate euro-object   */
  tmpEuro~betrag=Amount                                                         /* assign amount, object will calculate euro */
  self~set_euro(tmpEuro~euro_betrag)


::method rgf_msg  /* RGF */
  use arg id, msg
  self~setValue(id, msg)


::method dsp_euro /* RGF - display values */
  expose euroList euroDir

  betrag_id=201; waehrung_id=301        /* ID-Werte */
  DO item OVER euroList
     tmpEuro = euroDir~entry(item)
     IF tmpEuro~euro_betrag = 1 THEN stellen=6  /* rate of exchange ? */
                                ELSE stellen=2

     self~setvalue(betrag_id,   FORMAT( tmpEuro~betrag, , stellen) )	/* auf 2 Nachkommastellen */
     self~setvalue(waehrung_id, tmpEuro~waehrung "["tmpEuro~land"]")
     betrag_id=betrag_id+1; waehrung_id=waehrung_id+1
  END


::method set_euro /* RGF - set euro-value in all euro-objects */
  expose euroDir
  use arg amount
  DO index OVER euroDir
     euroDir[index]~euro_betrag=amount
  END
  self~dsp_euro	    /* display present values */

